const Config = () => {
    const isDev = process.env.NODE_ENV !== 'production';
    const makeBuild = (options) => ({
        extractCSS: !isDev,
        optimizeCSS: !isDev,
        parallel: true,
        babel: {
            plugins: [['@babel/plugin-proposal-private-property-in-object', { loose: true }]]
        },
        postcss: {
            plugins: {
                'postcss-custom-properties': false
            }
        },
        transpile: ['vee-validate/dist/rules'],
        extend(config, ctx) {
            if (ctx.isDev) {
                config.devtool = ctx.isClient ? 'source-map' : 'inline-source-map';
            }
        },
        publicPath: process.env.PUBLIC_PATH,
        ...options
    });
    const makeModules = (modules) => ([
        '@nuxtjs/pwa',
        'nuxt-precompress',
        '@vue-storefront/middleware/nuxt',
        'nuxt-i18n',
        'cookie-universal-nuxt',
        'vue-scrollto/nuxt',
        ['@vue-storefront/cache/nuxt', {
                enabled: !isDev,
                invalidation: {
                    endpoint: '/cache-invalidate',
                    key: '0ead60c3-d118-40be-9519-d531462ddc60',
                    handlers: ['@vue-storefront/cache/defaultHandler']
                },
                driver: [
                    '@vue-storefront/redis-cache',
                    {
                        defaultTimeout: 86400,
                        redis: {
                            host: process.env.REDIS_HOST,
                            port: process.env.REDIS_PORT,
                            password: process.env.REDIS_PASSWORD,
                            db: process.env.REDIS_DATABASE
                        }
                    }
                ]
            }
        ],
        ...(modules || [])
    ]);
    return {
        makeModules,
        makeBuild
    };
};

export { Config as default };
//# sourceMappingURL=index.es.js.map
